==> gedit_44.2.orig.tar.xz: gedit-44.2/plugins/list-of-gedit-plugins.md <==
gedit plugins
=============

Core plugins
------------

Plugins that are distributed with gedit itself.

- **Document Statistics** - *Report the number of words, lines and characters in a document.*
- **External Tools** - *Execute external commands and shell scripts.*
- **File Browser Panel** - *Easy file access from the side panel.*
- **Insert Date/Time** - *Inserts current date and time at the cursor position.*
- **Modelines** - *Emacs, Kate and Vim-style modelines support for gedit.*
- **Python Console** - *Interactive Python console standing in the bottom panel.*
- **Quick Highlight** - *Highlights every occurrences of selected text.*
- **Quick Open** - *Quickly open files.*
- **Snippets** - *Insert often-used pieces of text in a fast way.*
- **Sort** - *Sorts a document or selected text.*
- **Spell Checker** - *Checks the spelling of the current document.*

gedit-plugins package
---------------------

The gedit-plugins package contains useful plugins that are (most
of the time) too specific to be distributed with gedit itself.

- **Bookmarks** - *Easy document navigation with bookmarks*
- **Bracket Completion** - *Automatically adds closing brackets.*
- **Character Map** - *Insert special characters just by clicking on them.*
- **Code Comment** - *Comment out or uncomment a selected block of code.*
- **Color Picker** - *Pick a color from a dialog and insert its hexadecimal representation.*
- **Color Scheme Editor** - *Source code color scheme editor*
- **Draw Spaces** - *Draw spaces and tabs*
- **Embedded Terminal** - *Embed a terminal in the bottom pane.*
- **Git** - *Highlight lines that have been changed since the last commit*
- **Join/Split Lines** - *Join several lines or split long ones*
- **Multi Edit** - *Edit document in multiple places at once*
- **Session Saver** - *Save and restore your working sessions*
- **Smart Spaces** - *Forget you’re not using tabulations.*
- **SyncTeX** - *Synchronize between LaTeX and PDF with gedit and evince.*
- **Text Size** - *Easily increase and decrease the text size*
- **Word Completion** - *Word completion using the completion framework*

==> gedit_46.2.orig.tar.xz: gedit-46.2/plugins/list-of-gedit-plugins.md <==
gedit plugins
=============

Core plugins
------------

Plugins that are distributed with gedit itself.

- **Document Statistics** - *Report the number of words, lines and characters in a document.*
- **External Tools** - *Execute external commands and shell scripts.*
- **File Browser Panel** - *Easy file access from the side panel.*
- **Insert Date/Time** - *Inserts current date and time at the cursor position.*
- **Modelines** - *Emacs, Kate and Vim-style modelines support for gedit.*
- **Python Console** - *Interactive Python console standing in the bottom panel.*
- **Quick Highlight** - *Highlights every occurrences of selected text.*
- **Quick Open** - *Quickly open files.*
- **Snippets** - *Insert often-used pieces of text in a fast way.*
- **Sort** - *Sorts a document or selected text.*
- **Spell Checker** - *Checks the spelling of the current document.*

gedit-plugins package
---------------------

The gedit-plugins package contains useful plugins that are (most
of the time) too specific to be distributed with gedit itself.

- **Bookmarks** - *Easy document navigation with bookmarks*
- **Bracket Completion** - *Automatically adds closing brackets.*
- **Character Map** - *Insert special characters just by clicking on them.*
- **Code Comment** - *Comment out or uncomment a selected block of code.*
- **Color Picker** - *Pick a color from a dialog and insert its hexadecimal representation.*
- **Draw Spaces** - *Draw spaces and tabs*
- **Embedded Terminal** - *Embed a terminal in the bottom pane.*
- **Git** - *Highlight lines that have been changed since the last commit*
- **Join/Split Lines** - *Join several lines or split long ones*
- **Multi Edit** - *Edit document in multiple places at once*
- **Session Saver** - *Save and restore your working sessions*
- **Smart Spaces** - *Forget you’re not using tabulations.*
- **Text Size** - *Easily increase and decrease the text size*
- **Word Completion** - *Word completion using the completion framework*

Third-party plugins
-------------------

There are also [third-party gedit plugins](third-party-plugins.md).
